pub struct Polynomial<T> { /* private fields */ }Expand description
A polynomial represented as a vector of coefficients.
Implementations
Sourceimpl<T> Polynomial<T>
impl<T> Polynomial<T>
Sourcepub const fn new(coefficients: Vec<T>) -> Self
pub const fn new(coefficients: Vec<T>) -> Self
Create a new polynomial from a vector of coefficients.
Sourcepub fn from_coefficients(coefficients: &[T]) -> Selfwhere
T: Clone,
pub fn from_coefficients(coefficients: &[T]) -> Selfwhere
T: Clone,
Create a new polynomial from a slice of coefficients.
Sourcepub fn as_coefficients(self) -> Vec<T>
pub fn as_coefficients(self) -> Vec<T>
Gets the coefficients of the polynomial.
Sourcepub fn coefficients(&self) -> &[T]
pub fn coefficients(&self) -> &[T]
Gets the coefficients of the polynomial.
Sourcepub fn eval<S: AbstractExtensionField<T>>(&self, x: S) -> Swhere
T: AbstractField,
pub fn eval<S: AbstractExtensionField<T>>(&self, x: S) -> Swhere
T: AbstractField,
Evaluates the polynomial at a given point.
Sourcepub fn root_quotient(&self, r: T) -> Selfwhere
T: Field,
pub fn root_quotient(&self, r: T) -> Selfwhere
T: Field,
Computes the root quotient of the polynomial.
Sourceimpl Polynomial<u8>
impl Polynomial<u8>
Sourcepub fn as_field<F: Field>(self) -> Polynomial<F>
pub fn as_field<F: Field>(self) -> Polynomial<F>
Converts the polynomial to a field polynomial.